@font-face{font-family:Material Icons Outlined;font-style:normal;font-weight:400;src:url(./material-icons-outlined-35dca8a7.woff2) format("woff2")}@font-face{font-family:JetBrains Mono Medium;font-weight:400;font-style:normal;font-display:auto;src:url(./JetBrainsMono-Medium-086c48df.woff2) format("woff2")}.material-icons-outlined{font-family:Material Icons Outlined;font-weight:400;font-style:normal;font-size:24px;line-height:1;letter-spacing:normal;text-transform:none;display:inline-block;white-space:nowrap;word-wrap:normal;direction:ltr;-webkit-font-feature-settings:"liga";-webkit-font-smoothing:antialiased}html{overflow:hidden}*{-webkit-user-drag:none;-khtml-user-drag:none;-moz-user-drag:none;-o-user-drag:none;user-drag:none;-webkit-touch-callout:none;-webkit-user-select:none;-khtml-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}a{cursor:pointer}.v-btn--size-default{padding:0 8px}.vertical-btn{display:flex;flex-direction:column;align-items:center}.right{float:right}.left{float:left}.listitem-media-thumb{height:50px;width:50px;margin-right:10px}.v-slider.v-input--horizontal .v-input__control{min-height:5px}div.v-navigation-drawer__scrim{opacity:.8;background:grey}.v-card--variant-elevated{box-shadow:none;border-width:1px;border-style:solid;font-size:smaller}.line-clamp-2{white-space:pre-line;overflow:hidden;word-wrap:break-word;box-sizing:border-box;display:-webkit-box;-webkit-line-clamp:2}.v-card-text{padding-right:0}.v-expansion-panel--active>.v-expansion-panel-title{min-height:48px}.v-toolbar>.v-toolbar__content>.v-toolbar-title{margin-inline-start:25px}.v-toolbar>.v-toolbar__content>.v-toolbar__prepend{margin-inline-start:6px}.v-toolbar>.v-toolbar__content>.v-toolbar__append{margin-inline-end:21px}.v-toolbar-default>.v-toolbar__content>.v-toolbar-title{margin-inline-start:16px}.v-toolbar-default>.v-toolbar__content>.v-toolbar__prepend{margin-inline-start:10px}.v-toolbar-default>.v-toolbar__content>.v-toolbar__append{margin-inline-end:10px}.v-toolbar{height:55px}.v-toolbar-title{font-family:JetBrains Mono Medium}.col-2{width:50%;max-width:50%;flex-basis:50%}.col-3{width:33.3%;max-width:33.3%;flex-basis:33.3%}.col-4{width:25%;max-width:25%;flex-basis:25%}.col-5{width:20%;max-width:20%;flex-basis:20%}.col-6{width:16.6%;max-width:16.6%;flex-basis:16.6%}.col-7{width:14.2%;max-width:14.2%;flex-basis:14.2%}.col-8{width:12.5%;max-width:12.5%;flex-basis:12.5%}.col-9{width:11.1%;max-width:11.1%;flex-basis:11.1%}.line-clamp-1{white-space:nowrap;text-overflow:ellipsis;overflow:hidden}.line-clamp-2{white-space:pre-line;overflow:hidden;line-height:1.5em;height:3em;word-wrap:break-word;box-sizing:border-box;display:-webkit-box;-webkit-line-clamp:2}.small-icon{font-size:22px;height:22px;width:22px}.small-btn,.large-icon{font-size:40px;height:40px;width:40px}.large-btn{font-size:50px;height:50px;width:50px}.v-expansion-panel-title{border-radius:0}.v-input--horizontal .v-input__prepend{margin-inline-end:8px}.v-toolbar__content{height:100%!important}.padded-overlay .v-overlay__content{padding:50px}.v-overlay__scrim{opacity:65%}.v-expansion-panel-title{padding:10px}.flicking-camera{display:flex!important}.v-list-item-subtitle{font-size:.75rem;line-height:1rem;font-weight:400;margin-top:0;margin-bottom:0}.v-list-item-title{font-size:.875rem;line-height:1.25rem;font-weight:500}.v-toolbar-title{font-size:1.25rem;line-height:1.75rem;font-weight:500}.v-list-item--nav .v-list-item-title{font-size:.875rem;line-height:1.25rem;font-weight:500}h1{font-size:1.5rem;line-height:2rem;font-weight:500}h2{font-size:1.25rem;line-height:1.75rem;font-weight:500}h3{font-size:1.125rem;line-height:1.5rem;font-weight:500}h4{font-size:1rem;line-height:1.25rem;font-weight:700}h5{font-size:.875rem;line-height:1.25rem;font-weight:500}h6{font-size:.75rem;line-height:1rem;font-weight:400}.mh1{margin-top:1.5rem;margin-bottom:1rem}.mh2{margin-top:1.5rem;margin-bottom:.75rem}.mh3{margin-top:1.5rem;margin-bottom:.5rem}.mh4{margin-top:1.25rem;margin-bottom:.5rem}.mh5{margin-top:1rem;margin-bottom:.25rem}.mh6{margin-top:1rem;margin-bottom:0}.v-slide-group{display:flex;overflow:hidden}.v-slide-group__next,.v-slide-group__prev{align-items:center;display:flex;flex:0 1 52px;justify-content:center;min-width:52px;cursor:pointer}.v-slide-group__next--disabled,.v-slide-group__prev--disabled{pointer-events:none;opacity:var(--v-disabled-opacity)}.v-slide-group__content{display:flex;flex:1 0 auto;position:relative;transition:.2s all cubic-bezier(.4,0,.2,1);white-space:nowrap}.v-slide-group__content>*{white-space:initial}.v-slide-group__container{contain:content;display:flex;flex:1 1 auto;overflow:hidden}.v-slide-group--vertical,.v-slide-group--vertical .v-slide-group__container,.v-slide-group--vertical .v-slide-group__content{flex-direction:column}
