import{v as d,aa as m,c as v,R as g,y as l,E as f,l as t,A as a,Q as o,N as s,x as _,z as V,S as y,B as h,K as b}from"./index-5804982a.js";import{V as B,a as n}from"./VTabs-c9942f5e.js";import{V as k}from"./VToolbar-ce6590ba.js";import{k as S}from"./forwardRefs-03519353.js";import"./VSlideGroup-711de993.js";const T=h("div",{style:{height:"15px"}},null,-1),x=d({__name:"Settings",setup(C){const i=m(),u=v(()=>{var e,r;return(e=i.currentRoute.value.name)!=null&&e.toString().includes("player")?"players":(r=i.currentRoute.value.name)!=null&&r.toString().includes("core")?"core":"providers"});return(e,r)=>{const p=g("router-view");return l(),f("div",null,[t(k,{color:"transparent",title:_(b)("bp4")?e.$t("settings.settings"):""},{append:a(()=>[t(B,{"model-value":u.value,"align-tabs":"end",height:"100%"},{default:a(()=>[t(n,{value:"providers",to:{name:"providersettings"}},{default:a(()=>[o(s(e.$t("settings.providers")),1)]),_:1}),t(n,{value:"players",to:{name:"playersettings"}},{default:a(()=>[o(s(e.$t("settings.players")),1)]),_:1}),t(n,{value:"core",to:{name:"coresettings"}},{default:a(()=>[o(s(e.$t("settings.core")),1)]),_:1})]),_:1},8,["model-value"])]),_:1},8,["title"]),t(S),T,t(p,{app:""},{default:a(({Component:c})=>[(l(),V(y(c)))]),_:1})])}}});export{x as default};
