import{c as a,y as n,z as l,Y as p,G as c,A as _,_ as i,n as m}from"./index-5804982a.js";import{a as u}from"./Container-d5ee1f41.js";import{V as f}from"./VAlert-8600f5db.js";const d={setup(r,t){const e=a(()=>({}));return{alertProps:a(()=>({...e.value,...t.attrs}))}}};function y(r,t,e,s,A,$){return n(),l(f,m(s.alertProps,{class:"alert",color:"primary",density:"compact",prominent:""}),p({_:2},[c(r.$slots,(v,o)=>({name:o,fn:_(()=>[i(r.$slots,o)])}))]),1040)}const h=u(d,[["render",y]]);export{h as A};
