import{_ as l}from"./ItemsListing.vue_vue_type_style_index_0_lang-cfe67ae4.js";import{_ as d,a as v}from"./ProviderDetails.vue_vue_type_script_setup_true_lang-6ac061a5.js";import{v as f,r as h,w as k,y as i,E as y,l as b,z as a,x as w,I as o,B as m,L as s,ap as _}from"./index-5804982a.js";import"./ListviewItem-8b7ae6a6.js";import"./VBadge-3d00ada8.js";import"./Container-d5ee1f41.js";import"./forwardRefs-03519353.js";import"./VMenu-18f2572a.js";/* empty css              */import"./VInput-fe7a35fc.js";import"./VSlideGroup-711de993.js";import"./VCard-cc8044ef.js";import"./VCardText-963b2439.js";import"./VTooltip-5622a67d.js";import"./PanelviewItem.vue_vue_type_style_index_0_lang-04756f0a.js";import"./contextmenu-95007cdc.js";import"./Alert-38a1b933.js";import"./VAlert-8600f5db.js";import"./VToolbar-ce6590ba.js";import"./VTextField-b58cde95.js";import"./VVirtualScroll-72995e2a.js";import"./layout-b05dbcdd.js";import"./VDialog-c56f60de.js";const I=m("br",null,null,-1),g=m("br",null,null,-1),U=f({__name:"TrackDetails",props:{itemId:{},provider:{},album:{}},setup(n){const t=n,e=h(),p=async function(){e.value=await s.getTrack(t.itemId,t.provider,t.album)};k(()=>t.itemId,r=>{r&&p()},{immediate:!0});const u=async function(r){return await s.getTrackVersions(e.value.item_id,e.value.provider)},c=async function(r){return await s.getTrackAlbums(t.itemId,t.provider,r.libraryOnly)};return(r,T)=>(i(),y("section",null,[b(d,{item:e.value,"active-provider":r.provider},null,8,["item","active-provider"]),e.value?(i(),a(l,{key:0,itemtype:"trackalbums","parent-item":e.value,"show-provider":!0,"show-favorites-only-filter":!1,"show-library-only-filter":e.value.provider=="library"&&w(_)(e.value).length>0,"show-track-number":!1,"show-refresh-button":!1,"load-items":c,"sort-keys":["provider","name","duration"],title:r.$t("appears_on"),checksum:r.provider+r.itemId},null,8,["parent-item","show-library-only-filter","title","checksum"])):o("",!0),I,e.value?(i(),a(l,{key:1,itemtype:"trackversions","parent-item":e.value,"show-provider":!0,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":u,"show-refresh-button":!1,"sort-keys":["provider","name","duration"],title:r.$t("other_versions"),"hide-on-empty":!0,checksum:r.provider+r.itemId},null,8,["parent-item","title","checksum"])):o("",!0),g,e.value?(i(),a(v,{key:2,"item-details":e.value},null,8,["item-details"])):o("",!0)]))}});export{U as default};
