import{_ as u}from"./ItemsListing.vue_vue_type_style_index_0_lang-cfe67ae4.js";import{_ as f,a as v}from"./ProviderDetails.vue_vue_type_script_setup_true_lang-6ac061a5.js";import{v as _,r as h,w as y,y as a,E as w,l as V,z as m,I as n,B as k,L as s,ap as g}from"./index-5804982a.js";import"./ListviewItem-8b7ae6a6.js";import"./VBadge-3d00ada8.js";import"./Container-d5ee1f41.js";import"./forwardRefs-03519353.js";import"./VMenu-18f2572a.js";/* empty css              */import"./VInput-fe7a35fc.js";import"./VSlideGroup-711de993.js";import"./VCard-cc8044ef.js";import"./VCardText-963b2439.js";import"./VTooltip-5622a67d.js";import"./PanelviewItem.vue_vue_type_style_index_0_lang-04756f0a.js";import"./contextmenu-95007cdc.js";import"./Alert-38a1b933.js";import"./VAlert-8600f5db.js";import"./VToolbar-ce6590ba.js";import"./VTextField-b58cde95.js";import"./VVirtualScroll-72995e2a.js";import"./layout-b05dbcdd.js";import"./VDialog-c56f60de.js";const I=k("br",null,null,-1),T=_({__name:"RadioDetails",props:{itemId:{},provider:{}},setup(p){const t=p,e=h(),l=async function(){e.value=await s.getRadio(t.itemId,t.provider)};y(()=>t.itemId,i=>{i&&l()},{immediate:!0});const d=async function(i){const o=[];if(t.provider=="library"){const r=await s.getRadioVersions(t.itemId,t.provider);o.push(...r)}for(const r of g(e.value)){const c=await s.getRadioVersions(r.item_id,r.provider_instance);o.push(...c)}return o};return(i,o)=>(a(),w("section",null,[V(f,{item:e.value},null,8,["item"]),e.value?(a(),m(u,{key:0,itemtype:"radioversions","parent-item":e.value,"show-provider":!0,"show-favorites-only-filter":!1,"show-library":!1,"show-radio-number":!1,"show-duration":!1,"load-items":d,"sort-keys":["provider","sort_name"],title:i.$t("other_versions"),"hide-on-empty":!0,checksum:i.provider+i.itemId},null,8,["parent-item","title","checksum"])):n("",!0),I,e.value?(a(),m(v,{key:1,"item-details":e.value},null,8,["item-details"])):n("",!0)]))}});export{T as default};
