import{v as n,O as l,aa as c,c as u,K as a,y as h,E as f,l as w,L as b}from"./index-5804982a.js";import{_ as d}from"./ItemsListing.vue_vue_type_style_index_0_lang-cfe67ae4.js";import"./ListviewItem-8b7ae6a6.js";import"./VBadge-3d00ada8.js";import"./Container-d5ee1f41.js";import"./forwardRefs-03519353.js";import"./VMenu-18f2572a.js";/* empty css              */import"./VInput-fe7a35fc.js";import"./VSlideGroup-711de993.js";import"./VCard-cc8044ef.js";import"./VCardText-963b2439.js";import"./VTooltip-5622a67d.js";import"./PanelviewItem.vue_vue_type_style_index_0_lang-04756f0a.js";import"./contextmenu-95007cdc.js";import"./Alert-38a1b933.js";import"./VAlert-8600f5db.js";import"./VToolbar-ce6590ba.js";import"./VTextField-b58cde95.js";import"./VVirtualScroll-72995e2a.js";const A=n({__name:"BrowseView",props:{path:{}},setup(s){const t=s,{t:o}=l();c();const p=u(()=>!t.path||t.path=="root"?o("browse"):a("bp6")?o("browse")+" | "+t.path:a("bp3")?t.path:o("browse")),i=async function(e){const r=[];return await b.browse(t.path,m=>{r.push(...m)}),r};return(e,r)=>(h(),f("section",null,[w(d,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":i,"sort-keys":["original","name","name_desc"],title:p.value,path:e.path,"allow-key-hooks":!0},null,8,["title","path"])]))}});export{A as default};
