import{_ as s}from"./ItemsListing.vue_vue_type_style_index_0_lang-cfe67ae4.js";import{_ as y,a as v}from"./ProviderDetails.vue_vue_type_script_setup_true_lang-6ac061a5.js";import{v as h,r as b,w,y as i,E as _,l as k,z as a,x as n,I as o,B as p,L as l,ap as m}from"./index-5804982a.js";import"./ListviewItem-8b7ae6a6.js";import"./VBadge-3d00ada8.js";import"./Container-d5ee1f41.js";import"./forwardRefs-03519353.js";import"./VMenu-18f2572a.js";/* empty css              */import"./VInput-fe7a35fc.js";import"./VSlideGroup-711de993.js";import"./VCard-cc8044ef.js";import"./VCardText-963b2439.js";import"./VTooltip-5622a67d.js";import"./PanelviewItem.vue_vue_type_style_index_0_lang-04756f0a.js";import"./contextmenu-95007cdc.js";import"./Alert-38a1b933.js";import"./VAlert-8600f5db.js";import"./VToolbar-ce6590ba.js";import"./VTextField-b58cde95.js";import"./VVirtualScroll-72995e2a.js";import"./layout-b05dbcdd.js";import"./VDialog-c56f60de.js";const g=p("br",null,null,-1),A=p("br",null,null,-1),R=h({__name:"ArtistDetails",props:{itemId:{},provider:{}},setup(u){const r=u,t=b(),c=async function(){t.value=await l.getArtist(r.itemId,r.provider)};w(()=>r.itemId,e=>{e&&c()},{immediate:!0});const d=async function(e){return await l.getArtistAlbums(r.itemId,r.provider,e.libraryOnly)},f=async function(e){return await l.getArtistTracks(r.itemId,r.provider,e.libraryOnly)};return(e,I)=>(i(),_("section",null,[k(y,{item:t.value},null,8,["item"]),t.value?(i(),a(s,{key:0,itemtype:"artisttracks","parent-item":t.value,"show-provider":!0,"show-favorites-only-filter":!0,"show-library-only-filter":t.value.provider=="library"&&n(m)(t.value).length>0,"show-refresh-button":!1,"show-track-number":!1,"load-items":f,"sort-keys":["recent","name","album"],title:e.$t("tracks"),"allow-collapse":!0},null,8,["parent-item","show-library-only-filter","title"])):o("",!0),g,t.value?(i(),a(s,{key:1,itemtype:"artistalbums","parent-item":t.value,"show-provider":!0,"show-favorites-only-filter":!0,"show-library-only-filter":t.value.provider=="library"&&n(m)(t.value).length>0,"show-refresh-button":!1,"load-items":d,"sort-keys":["recent","name","year"],title:e.$t("albums"),"allow-collapse":!0},null,8,["parent-item","show-library-only-filter","title"])):o("",!0),A,t.value?(i(),a(v,{key:2,"item-details":t.value},null,8,["item-details"])):o("",!0)]))}});export{R as default};
