.panel-item{height:100%;padding:10px;border:none;border-style:none!important}.panel-item-checkbox{position:absolute;left:0;top:0}.panel-item-details{padding-left:0!important;padding-right:0!important}.hiresicon{margin-left:10px;margin-right:10px}.hiresiconinverted{margin-left:10px;margin-right:10px;filter:invert(100%)}
