import{m as w,a as H,u as M,b as h,c as C}from"./VInput-fe7a35fc.js";import{p as y,aC as G,g,h as S,at as B,c as v,aM as R,l as V,n as p,v as z,y as D,z as L,x as N,H as I,L as W,d as j,e as q,r as E}from"./index-5804982a.js";import{i as T,a as J,p as K,d as Q,r as X,G as Y,H as Z,F as _}from"./forwardRefs-03519353.js";import{B as ee}from"./Container-d5ee1f41.js";import{m as te,a as oe,f as x}from"./VMenu-18f2572a.js";const ae=y({...w(),...G(H(),["inline"])},"VCheckbox"),de=g()({name:"VCheckbox",inheritAttrs:!1,props:ae(),emits:{"update:modelValue":e=>!0,"update:focused":e=>!0},setup(e,s){let{attrs:t,slots:o}=s;const a=S(e,"modelValue"),{isFocused:r,focus:i,blur:n}=M(e),u=B(),l=v(()=>e.id||`checkbox-${u}`);return T(()=>{const[b,k]=R(t),P=h.filterProps(e),c=C.filterProps(e);return V(h,p({class:["v-checkbox",e.class]},b,P,{modelValue:a.value,"onUpdate:modelValue":d=>a.value=d,id:l.value,focused:r.value,style:e.style}),{...o,default:d=>{let{id:m,messagesId:f,isDisabled:$,isReadonly:A,isValid:O}=d;return V(C,p(c,{id:m.value,"aria-describedby":f.value,disabled:$.value,readonly:A.value},k,{error:O.value===!1,modelValue:a.value,"onUpdate:modelValue":U=>a.value=U,onFocus:i,onBlur:n}),o)}})}),{}}}),me=z({__name:"FavoriteButton",props:{item:{}},setup(e){const s=e;return(t,o)=>{var a;return D(),L(ee,p(s,{variant:"list",icon:(a=t.item)!=null&&a.favorite?"mdi-heart":"mdi-heart-outline",title:t.$t("tooltip.favorite"),onClick:[o[0]||(o[0]=r=>N(W).toggleFavorite(t.item)),o[1]||(o[1]=I(()=>{},["prevent"])),o[2]||(o[2]=I(()=>{},["stop"]))]}),null,16,["icon","title"])}}});const F=Symbol.for("vuetify:v-item-group"),se=y({...J(),...K({selectedClass:"v-item--selected"}),...Q(),...j()},"VItemGroup"),ve=g()({name:"VItemGroup",props:se(),emits:{"update:modelValue":e=>!0},setup(e,s){let{slots:t}=s;const{themeClasses:o}=q(e),{isSelected:a,select:r,next:i,prev:n,selected:u}=X(e,F);return()=>V(e.tag,{class:["v-item-group",o.value,e.class],style:e.style},{default:()=>{var l;return[(l=t.default)==null?void 0:l.call(t,{isSelected:a,select:r,next:i,prev:n,selected:u.value})]}})}}),pe=g()({name:"VItem",props:Y(),emits:{"group:selected":e=>!0},setup(e,s){let{slots:t}=s;const{isSelected:o,select:a,toggle:r,selectedClass:i,value:n,disabled:u}=Z(e,F);return()=>{var l;return(l=t.default)==null?void 0:l.call(t,{isSelected:o.value,selectedClass:i.value,select:a,toggle:r,value:n.value,disabled:u.value})}}});const le=y({id:String,text:String,...G(te({closeOnBack:!1,location:"end",locationStrategy:"connected",eager:!0,minWidth:0,offset:10,openOnClick:!1,openOnHover:!0,origin:"auto",scrim:!1,scrollStrategy:"reposition",transition:!1}),["absolute","persistent"])},"VTooltip"),fe=g()({name:"VTooltip",props:le(),emits:{"update:modelValue":e=>!0},setup(e,s){let{slots:t}=s;const o=S(e,"modelValue"),{scopeId:a}=oe(),r=B(),i=v(()=>e.id||`v-tooltip-${r}`),n=E(),u=v(()=>e.location.split(" ").length>1?e.location:e.location+" center"),l=v(()=>e.origin==="auto"||e.origin==="overlap"||e.origin.split(" ").length>1||e.location.split(" ").length>1?e.origin:e.origin+" center"),b=v(()=>e.transition?e.transition:o.value?"scale-transition":"fade-transition"),k=v(()=>p({"aria-describedby":i.value},e.activatorProps));return T(()=>{const P=x.filterProps(e);return V(x,p({ref:n,class:["v-tooltip",e.class],style:e.style,id:i.value},P,{modelValue:o.value,"onUpdate:modelValue":c=>o.value=c,transition:b.value,absolute:!0,location:u.value,origin:l.value,persistent:!0,role:"tooltip",activatorProps:k.value,_disableGlobalStack:!0},a),{activator:t.activator,default:function(){var f;for(var c=arguments.length,d=new Array(c),m=0;m<c;m++)d[m]=arguments[m];return((f=t.default)==null?void 0:f.call(t,...d))??e.text}})}),_({},n)}});export{fe as V,me as _,de as a,ve as b,pe as c};
