import{c as o,y as r,z as p,Y as M,G as $,A as d,_ as k,n as h,v as z,L as i,E as m,x as l,D as g,R as V,l as f,F as C,I as P,a6 as L,p as w,g as B,u as A}from"./index-5804982a.js";import{l as x,n as b,a as D,d as S,i as T}from"./forwardRefs-03519353.js";import{e as H,b as R,d as F,V as E}from"./VMenu-18f2572a.js";/* empty css              */const N={props:{variant:{type:String,default:"default",validator:t=>["plain","default","responsive","icon","list"].includes(t)}},setup(t,a){const e={},n=o(()=>({...e,class:"v-btn--variant-responsive",ripple:!0,icon:!0,style:"height: min(calc(100vw - 40px), calc(100vh - 340px)); width: min(calc(100vw - 40px), calc(100vh - 340px));"})),u=o(()=>({...e,ripple:!1})),v=o(()=>({...e,density:"comfortable"}));return{btnProps:o(()=>{switch(t.variant){case"default":return e;case"plain":return e;case"responsive":return n.value;case"icon":return u.value;case"list":return v.value;default:return e}})}}};const I=(t,a)=>{const e=t.__vccOpts||t;for(const[n,u]of a)e[n]=u;return e};function G(t,a,e,n,u,v){return r(),p(x,h(n.btnProps,{variant:"plain"}),M({_:2},[$(t.$slots,(_,c)=>({name:c,fn:d(()=>[k(t.$slots,c)])}))]),1040)}const O=I(N,[["render",G]]),Y=["title","innerHTML"],j=["title","innerHTML"],se=z({__name:"ProviderIcon",props:{domain:{},size:{},dark:{type:Boolean}},setup(t){const a=t,e=o(()=>a.domain in i.providers?i.providers[a.domain].domain:a.domain);return(n,u)=>(r(),m("div",{style:g(`width:${n.size}px;margin-left:10px;margin-right:10px`)},[e.value=="library"?(r(),p(b,{key:0,size:n.size,icon:"mdi-bookshelf",title:n.$t("item_in_library")},null,8,["size","title"])):n.$vuetify.theme.current.dark&&l(i).providerManifests[e.value].icon_svg_dark?(r(),m("div",{key:1,style:g(`width: ${n.size}px`),title:l(i).providerManifests[e.value].name,innerHTML:l(i).providerManifests[e.value].icon_svg_dark},null,12,Y)):l(i).providerManifests[e.value].icon_svg?(r(),m("div",{key:2,style:g(`width: ${n.size}px;height: ${n.size}px`),title:l(i).providerManifests[e.value].name,innerHTML:l(i).providerManifests[e.value].icon_svg},null,12,j)):l(i).providerManifests[e.value].icon?(r(),p(b,{key:3,size:n.size,icon:"mdi-"+l(i).providerManifests[e.value].icon,title:l(i).providerManifests[e.value].name,dark:n.$vuetify.theme.current.dark},null,8,["size","icon","title","dark"])):(r(),p(b,{key:4,size:n.size,dark:n.$vuetify.theme.current.dark,icon:"mdi-playlist-play"},null,8,["size","dark"]))],4))}}),q={components:{MAButton:O},props:{contextMenuItems:{type:Array,default:[]}},setup(t,a){const e=o(()=>({}));return{listItemProps:o(()=>({...e.value,...a.attrs}))}}};const J={key:0,class:"contextmenubtn"};function K(t,a,e,n,u,v){const _=V("MAButton"),c=V("ListItem",!0);return r(),p(E,h(n.listItemProps,{class:"list-item-main",onInput:a[0]||(a[0]=s=>t.$emit("input",s))}),M({_:2},[$(t.$slots,(s,y)=>({name:y,fn:d(()=>[k(t.$slots,y)])})),t.$slots.append?{name:"append",fn:d(()=>[k(t.$slots,"append"),e.contextMenuItems.length>0?(r(),m("div",J,[f(H,{location:"bottom end"},{activator:d(({props:s})=>[f(_,h(s,{variant:"list",icon:"mdi-dots-vertical"}),null,16)]),default:d(()=>[f(R,null,{default:d(()=>[(r(!0),m(C,null,$(e.contextMenuItems.filter(s=>s.hide!=!0),(s,y)=>(r(),p(c,{key:y,title:t.$t(s.label,s.labelArgs),disabled:s.disabled==!0,onClick:Z=>s.action?s.action():""},{prepend:d(()=>[f(F,{icon:s.icon},null,8,["icon"])]),_:2},1032,["title","disabled","onClick"]))),128))]),_:1})]),_:1})])):P("",!0)]),key:"0"}:void 0]),1040)}const re=I(q,[["render",K]]),Q={props:{variant:{type:String,default:"default",validator:t=>["default","panel"].includes(t)}},setup(t,a){const e=o(()=>({class:"container-default"})),n=o(()=>({class:L.theme.current.value.dark?"container-default container-panels-dark":"container-default container-panels-light"}));return{btnProps:o(()=>{switch(t.variant){case"default":return e.value;case"panel":return n.value;default:return e.value}})}}};const U=w({fluid:{type:Boolean,default:!1},...D(),...S()},"VContainer"),W=B()({name:"VContainer",props:U(),setup(t,a){let{slots:e}=a;const{rtlClasses:n}=A();return T(()=>f(t.tag,{class:["v-container",{"v-container--fluid":t.fluid},n.value,t.class],style:t.style},e)),{}}});function X(t,a,e,n,u,v){return r(),p(W,h(n.btnProps,{variant:"default",fluid:""}),M({_:2},[$(t.$slots,(_,c)=>({name:c,fn:d(()=>[k(t.$slots,c)])}))]),1040)}const ie=I(Q,[["render",X]]);export{O as B,ie as C,re as L,se as _,I as a};
